@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aws
 version: 0.13.0
-id: aws-0.13.0-9871acc1012a59822ddfb02a5b5cff95
-key: aws_4VYhXuYBlmMCAIk0v0Gcz8
+id: aws-0.13.0-0f46a4bdfae8fbffb3594613b97c34da
+key: aws_0FsmBkWKHye8HrFDysXNyc
 license: BSD3
 copyright: See contributors list in README and LICENSE file
 maintainer: aristidb@gmail.com
@@ -55,7 +55,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aws-0.13.0
-hs-libraries: HSaws-0.13.0-4VYhXuYBlmMCAIk0v0Gcz8
+hs-libraries: HSaws-0.13.0-0FsmBkWKHye8HrFDysXNyc
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
@@ -67,21 +67,21 @@ depends:
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
+    cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
+    http-conduit-2.1.8-52d716dea2bf146bfe94bcf5c020ce6a
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
+    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
@@ -91,7 +91,7 @@ depends:
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    xml-conduit-1.3.4-2cb0835929c2dc7743cd241414dfd06a
+    xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
 haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
 haddock-html: /usr/share/doc/haskell-aws/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
